import { Component, OnInit } from '@angular/core';
import {environment} from '../../../../environments/environment';
import {FormBuilder, FormGroup} from '@angular/forms';
import {IconService} from '../../../services/icon.service';
import {NzMessageService} from 'ng-zorro-antd';
import {AgentService} from '../../../services/agent.service';
import {LocalStorageService} from '../../../services/local-storage.service';
import {ADMIN_INFO_OBJECT} from '../../../services/local-storage.namespace';

@Component({
  selector: 'app-order-coupons',
  templateUrl: './order-coupons.component.html',
  styleUrls: ['./order-coupons.component.scss']
})
export class OrderCouponsComponent implements OnInit {

  searchForm: FormGroup; // 搜索框
  requestData = []; // 列表数据
  total: number; // 页码
  pageNum = 1; // 页码
  pageSize = 10; // 条码
  loading = true;

  requestDataCode = []; // 列表数据
  totalCode: number; // 页码
  pageNumCode = 1; // 页码
  pageSizeCode = 10; // 条码
  loadingCode = true;
  isVisible = false;
  id: number;
  constructor(
      private form: FormBuilder,
      private agent: AgentService,
      private iconService: IconService,
      private message: NzMessageService,
      private store: LocalStorageService, // 数据请求
  ) {
  }

  ngOnInit(): void {
    this.init();
  }

  public init(): void {
    this.searchForm = this.form.group({
      status: [null],
    });
    this.getRequest(true, {});
  }

  // 查询列表
  public getRequest(reset: boolean = false, whereObject: object) {
    this.loading = false;
    if (reset) {
      this.pageNum = 1;
    }
    whereObject['agentId'] = this.store.get(ADMIN_INFO_OBJECT)['highAgent'].id;
    whereObject['pageNum'] = this.pageNum;
    whereObject['pageSize'] = this.pageSize;
    this.agent.getDiscountAgentList(whereObject, data => {
      if (data['return_code'] === '000000') {
        this.requestData = data['return_data'].list;
        this.total = data['return_data'].total;
      } else {
        this.message.error(data['return_msg']);
      }
    });
  }

  // 重置
  public resetForm(): void {
    this.searchForm.reset();
  }

  // 查看使用情况
  public getDetail(id: number): void {
    this.id = id;
    this.getRequestCode(false , this.searchForm.value);
    this.isVisible = true;
  }

  // 查询列表
  public getRequestCode(reset: boolean = false, whereObject: object) {
    this.loadingCode = true;
    if (reset) {
      this.pageNumCode = 1;
    }
    this.searchForm.value['discountAgentId'] = this.id;
    whereObject['pageNum'] = this.pageNumCode;
    whereObject['pageSize'] = this.pageSizeCode;
    this.agent.getDiscountCodeList(whereObject, data => {
      this.loadingCode = false;
      if (data['return_code'] === '000000') {
        this.requestDataCode = data['return_data'].list;
        this.totalCode = data['return_data'].total;
      } else {
        this.message.error(data['return_msg']);
      }
    });
  }

  handleOk(): void {
    this.isVisible = false;
  }

  handleCancel(): void {
    this.isVisible = false;
  }

}
